@@ -1,7 +1,9 @@
 package Dist::Zilla::Plugin::WordList;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2020-05-01'; # DATE
-our $VERSION = '0.055'; # VERSION
+our $DIST = 'Dist-Zilla-Plugin-WordList'; # DIST
+our $VERSION = '0.056'; # VERSION
 
 use 5.014;
 use strict;
@@ -83,15 +85,15 @@ sub munge_files {
                 });
             $stats{avg_word_len} = $total_len / $stats{num_words} if $total_len;
 
-            $content =~ s{^(#\s*STATS)$}{"our \%STATS = ".dmp(%stats)."; " . $1}em
-                or die "Can't replace #STATS for ".$file->name.", make sure you put the #STATS placeholder in modules";
-            $self->log(["replacing #STATS for %s", $file->name]);
-
             # old alias, for backward compat
             $stats{num_words_contains_unicode} = $stats{num_words_contain_unicode};
             $stats{num_words_contains_whitespace} = $stats{num_words_contain_whitespace};
             $stats{num_words_contains_nonword_chars} = $stats{num_words_contain_nonword_chars};
 
+            $content =~ s{^(#\s*STATS)$}{"our \%STATS = ".dmp(%stats)."; " . $1}em
+                or die "Can't replace #STATS for ".$file->name.", make sure you put the #STATS placeholder in modules";
+            $self->log(["replacing #STATS for %s", $file->name]);
+
             $file->content($content);
         }
     } # foreach file
@@ -114,7 +116,7 @@ Dist::Zilla::Plugin::WordList - Plugin to use when building WordList::* distribu
 
 =head1 VERSION
 
-This document describes version 0.055 of Dist::Zilla::Plugin::WordList (from Perl distribution Dist-Zilla-Plugin-WordList), released on 2020-05-01.
+This document describes version 0.056 of Dist::Zilla::Plugin::WordList (from Perl distribution Dist-Zilla-Plugin-WordList), released on 2020-05-01.
 
 =head1 SYNOPSIS
 
